{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2017-2018 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{%- extends config.THEME_HEADER_TEMPLATE %}

{#- Remove search field from top bar on frontpage #}
{%- block navbar_search %}{% endblock %}

{%- block navbar %}
{{super()}}

{%- block frontpage_search %}
<div class="ui two column centered grid container cover-page">
  <div class="row"></div>
  <div class="sixteen wide column frontpage-search">
    {%- block frontpage_title %}
    <h1 class="ui center aligned header">
        {{_(config.THEME_FRONTPAGE_TITLE)}}
    </h1>
    {%- endblock frontpage_title %}
    {%- block frontpage_form %}
    <form action="/search" class="ui form">
      <div class="ui fluid action input">
        <input type="text" name="q" class="form-control" placeholder="Type and press enter to search">
          <button type="submit" class="ui icon button"><i class="search icon"></i></button>
      </div>
    </form>
    {%- endblock frontpage_form %}
  </div>
  <div class="row"></div>
  <div class="row"></div>
</div>

{%- endblock frontpage_search %}

{% endblock %}
