{# -*- coding: utf-8 -*- This file is part of Invenio. Copyright (C) 2015-2018
CERN. Invenio is free software; you can redistribute it and/or modify it under
the terms of the MIT License; see LICENSE file for more details. #}

{% extends
config.THEME_BASE_TEMPLATE %} {%- set html_css_classes=['cover-page'] %} {%- set
body_css_classes=['cover-page'] %} {%- block body %} {%- block browserupgrade %}
<!--[if lt IE 8]>
  <p class="browserupgrade">
    You are using an <strong>outdated</strong> browser. Please
    <a href="http://browsehappy.com/">upgrade your browser</a> to improve your
    experience.
  </p>
<![endif]-->
{%- endblock browserupgrade %}
<div class="site-wrapper">
  {%- block flashmessages %} {%- from "invenio_theme/macros/messages.html"
  import flashed_messages with context -%} {{ flashed_messages() }} {%- endblock
  flashmessages %} {% block page_header %}
  <div class="ui two column centered grid">
    <div class="row"></div>
    <div class="row"></div>
    <div class="column">
      {%- block brand %} {%- if config.THEME_LOGO %}
      <a href="/">
        <img
          class="ui centered image masthead-brand"
          src="{{ url_for('static', filename=config.THEME_LOGO)}}"
          alt="{{ _(config.THEME_SITENAME) }}"
          width="250px"
        />
      </a>
      {%- elif config.THEME_SITENAME %}
      <a href="/" class="text-center masthead-brand">
        {{ _(config.THEME_SITENAME) }}
      </a>
      {% endif %} {%- endblock %}
    </div>
  </div>
  {% endblock page_header%} {%- block page_body %}
  <div class="container">
    <div class="row panel-container">
      {% block panel %}
      <div class="col-md-6 col-md-offset-3">
        <div class="panel panel-default">
          <div class="panel-body">
            {% block panel_content %}
            <h3 class="text-center panel-free-title">{{ panel_title }}</h3>
            {% endblock panel_content %}
          </div>
        </div>
      </div>
      {% endblock panel %}
    </div>
  </div>
  {%- endblock page_body %} {% block page_footer %} {% endblock page_footer %}
</div>
{%- block javascript %}{% include config.THEME_JAVASCRIPT_TEMPLATE %}{% endblock
javascript %} {%- block trackingcode %}{% include
config.THEME_TRACKINGCODE_TEMPLATE %}{% endblock %} {%- endblock body %}
